==> prestashop_1.4.9.0.zip: prestashop/modules/wexpay/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();
$_MODULE['<{wexpay}prestashop>payment_5805928fa133f0fb2fac14cecd73a6b5'] = 'Payer avec weXpay';
$_MODULE['<{wexpay}prestashop>payment_4d3220c7e70d278cece5139995a29237'] = 'Logo weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_8778298c8e187d72ec77eb2a6634812f'] = 'weXpay e-money';
$_MODULE['<{wexpay}prestashop>wexpay_5b9eef8a276759a4b2122f7097825a77'] = 'Accepter les paiements par weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_69a1a3ad8dd5da6db3c4da838a0cf9c7'] = 'Etes vous sur de vouloir supprimer les données ?';
$_MODULE['<{wexpay}prestashop>wexpay_5a414f8dfb934b6c05e1676e7b0307d2'] = 'L\'identifiant commerçant doit être configuré pour pouvoir utiliser weXpay comme méthode de paiement';
$_MODULE['<{wexpay}prestashop>wexpay_bd75168ae48056ee3026f8a3b87bb5da'] = 'L\'identifiant commerçant est requis';
$_MODULE['<{wexpay}prestashop>wexpay_444bcb3a3fcf8389296c49467f27e1d6'] = 'ok';
$_MODULE['<{wexpay}prestashop>wexpay_c888438d14855d7d96a2724ee9c306bd'] = 'Données mises à jour';
$_MODULE['<{wexpay}prestashop>wexpay_0df9cc7ad04a959cb8432d6ec327222c'] = 'weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_8f846561551613906b8a5429f0a7abf1'] = 'Contactez l\'équipe weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_594b3fc829f2463b05ca5296131b46da'] = 'Contactez nous / ou faites vous appeler par un de nos chargés de clientèle :';
$_MODULE['<{wexpay}prestashop>wexpay_740fcd51b628fa236106fb3e86304932'] = 'E-mail :';
$_MODULE['<{wexpay}prestashop>wexpay_8facaab55e30017fbabd1ffe4fc2321c'] = 'Tel : 01 46 08 68 94';
$_MODULE['<{wexpay}prestashop>wexpay_82dfb6f3b980b8698f690e0ac058dac7'] = 'Faites une demande d`information ou de contrat et nous vous rappelons :';
$_MODULE['<{wexpay}prestashop>wexpay_8c4275d2a9d00faf2ea278f5c411d79e'] = 'Ce module vous permet d\'accepter les paiements en espèces avec weXpay.';
$_MODULE['<{wexpay}prestashop>wexpay_0f24676f0a27673249ba0c072a17ed8b'] = 'Payer en espèces sur Internet, aujourd\'hui c\'est possible ! weXpay permet à votre boutique de capter une nouvelle clientèle en lui proposant la solution de paiement la plus simple : les espèces !';
$_MODULE['<{wexpay}prestashop>wexpay_f58e7ca3c47985c61c52de001fbd3aae'] = 'Grâce à son réseau de distribution weXpay permet à l\'internaute de changer ses espèces contre un code qui a les mêmes propriétés qu\'un billet de banque : il est utilisable par tous autant de fois que nécessaire, divisible au centime d\'Euros et cumulable,';
$_MODULE['<{wexpay}prestashop>wexpay_78a48072710bdc20e5d231a00f63a5fd'] = 'L\'installation est facile, rapide et gratuite, les paiements sont sécurisés et 100% garantis !';
$_MODULE['<{wexpay}prestashop>wexpay_a502f87e163942433dc02f2d6448fb33'] = 'Sans frais fixes ni frais cachés.';
$_MODULE['<{wexpay}prestashop>wexpay_093e4a645283f4820612cec4a3da54af'] = 'weXpay est la solution alternative à la carte bancaire qui bénéficie d\'un agrément d\'Emetteur de Monnaie Electronique de la Banque de France.';
$_MODULE['<{wexpay}prestashop>wexpay_0d509a9da3742d6f80b92dcf25d2904f'] = 'Avec des tarifs attractifs, weXpay vous permet de proposer un moyen de paiement en espèces quelle que soit votre activité marchande.';
$_MODULE['<{wexpay}prestashop>wexpay_9bb7109a5c7c473d8e7421a361f671a2'] = 'Pour plus d\'infos :';
$_MODULE['<{wexpay}prestashop>wexpay_254f642527b45bc260048e30704edb39'] = 'Configuration';
$_MODULE['<{wexpay}prestashop>wexpay_59586aa62e3b7e6e8c3aa86a2bcd8151'] = 'Créer un compte weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_cee9b3fae20d134d90dc128003aa81ec'] = 'Rien de plus simple, il vous suffit de vous rendre sur notre espace site marchand, et de remplir le formulaire de demande de contrat';
$_MODULE['<{wexpay}prestashop>wexpay_fe5fd4c042f1274174aec1c90a031e78'] = 'Activer facilement et gratuitement weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_d12218dc35a4cf0cd657c53a54725d4a'] = 'Vous avez signé un contrat avec weXpay, et vous avez reçu vos codes d\'activation dans un mail de bienvenue weXpay - Procédure = entrez vos indentifiant weXpay dans Prestashop pour activer le module et réalisez 3 transactions de test avec les codes de tests fournis dans le mail de bienvenue.';
$_MODULE['<{wexpay}prestashop>wexpay_96b34a13ce0fa2dd530e3c1a8cfeb1d0'] = 'Identifiant commerçant weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_b17f3f4dcf653a5776792498a9b44d6a'] = 'Mettre à jour';
$_MODULE['<{wexpay}prestashop>wexpay_0731cca0fad637eef981cc1e55ff39d4'] = 'Une fois que les transactions sont validées avec succès, connectez-vous à votre espace partenaire weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_fd97030fded8ca936e46eaf835bda6f9'] = ': uploadez votre logo, et appuyer sur le bouton';
$_MODULE['<{wexpay}prestashop>wexpay_f93c54c7fabede2357a9ae7f9d21c7c3'] = '\"passage en production.\"';
$_MODULE['<{wexpay}prestashop>wexpay_a7d192c13f259fd2c8b1c918142c43e7'] = 'Pour plus d\'infos, cliquez-ici';
$_MODULE['<{wexpay}prestashop>wexpay_506fa25b2c14cf4d619dca91f1d6a970'] = ': acceptez le paiement en espèces et augmentez votre chiffre d\'affaires !';

==> prestashop_1.4.11.1.zip: prestashop/modules/wexpay/fr.php <==
<?php

global $_MODULE;
$_MODULE = array();

$_MODULE['<{wexpay}prestashop>payment_5805928fa133f0fb2fac14cecd73a6b5'] = 'Payer avec weXpay';
$_MODULE['<{wexpay}prestashop>payment_4d3220c7e70d278cece5139995a29237'] = 'Logo weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_8778298c8e187d72ec77eb2a6634812f'] = 'weXpay e-money';
$_MODULE['<{wexpay}prestashop>wexpay_5b9eef8a276759a4b2122f7097825a77'] = 'Acceptez le paiement en espèces sur votre site !';
$_MODULE['<{wexpay}prestashop>wexpay_69a1a3ad8dd5da6db3c4da838a0cf9c7'] = 'Etes vous sur de vouloir supprimer les données ?';
$_MODULE['<{wexpay}prestashop>wexpay_5a414f8dfb934b6c05e1676e7b0307d2'] = 'L\'identifiant commerçant doit être configuré pour pouvoir utiliser weXpay comme méthode de paiement';
$_MODULE['<{wexpay}prestashop>wexpay_bd75168ae48056ee3026f8a3b87bb5da'] = 'L\'identifiant commerçant est requis';
$_MODULE['<{wexpay}prestashop>wexpay_444bcb3a3fcf8389296c49467f27e1d6'] = 'ok';
$_MODULE['<{wexpay}prestashop>wexpay_c888438d14855d7d96a2724ee9c306bd'] = 'Données mises à jour';
$_MODULE['<{wexpay}prestashop>wexpay_0df9cc7ad04a959cb8432d6ec327222c'] = 'weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_8f846561551613906b8a5429f0a7abf1'] = 'Contactez l\'équipe weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_594b3fc829f2463b05ca5296131b46da'] = 'Contactez nous / ou faites vous appeler par un de nos chargés de clientèle :';
$_MODULE['<{wexpay}prestashop>wexpay_740fcd51b628fa236106fb3e86304932'] = 'E-mail :';
$_MODULE['<{wexpay}prestashop>wexpay_8facaab55e30017fbabd1ffe4fc2321c'] = 'Tel : 01 46 08 68 94';
$_MODULE['<{wexpay}prestashop>wexpay_82dfb6f3b980b8698f690e0ac058dac7'] = 'Faites une demande d`information ou de contrat et nous vous rappelons :';
$_MODULE['<{wexpay}prestashop>wexpay_8c4275d2a9d00faf2ea278f5c411d79e'] = 'Ce module vous permet d\'accepter les paiements en espèces avec weXpay.';
$_MODULE['<{wexpay}prestashop>wexpay_0f24676f0a27673249ba0c072a17ed8b'] = 'Payer en espèces sur Internet, aujourd\'hui c\'est possible ! weXpay permet à votre boutique de capter une nouvelle clientèle en lui proposant la solution de paiement la plus simple : les espèces !';
$_MODULE['<{wexpay}prestashop>wexpay_f58e7ca3c47985c61c52de001fbd3aae'] = 'Grâce à son réseau de distribution weXpay permet à l\'internaute de changer ses espèces contre un code qui a les mêmes propriétés qu\'un billet de banque : il est utilisable par tous autant de fois que nécessaire, divisible au centime d\'Euros et cumulable,';
$_MODULE['<{wexpay}prestashop>wexpay_78a48072710bdc20e5d231a00f63a5fd'] = 'L\'installation est facile, rapide et gratuite, les paiements sont sécurisés et 100% garantis !';
$_MODULE['<{wexpay}prestashop>wexpay_a502f87e163942433dc02f2d6448fb33'] = 'Sans frais fixes ni frais cachés.';
$_MODULE['<{wexpay}prestashop>wexpay_093e4a645283f4820612cec4a3da54af'] = 'weXpay est la solution alternative à la carte bancaire qui bénéficie d\'un agrément d\'Emetteur de Monnaie Electronique de la Banque de France.';
$_MODULE['<{wexpay}prestashop>wexpay_0d509a9da3742d6f80b92dcf25d2904f'] = 'Avec des tarifs attractifs, weXpay vous permet de proposer un moyen de paiement en espèces quelle que soit votre activité marchande.';
$_MODULE['<{wexpay}prestashop>wexpay_9bb7109a5c7c473d8e7421a361f671a2'] = 'Pour plus d\'infos :';
$_MODULE['<{wexpay}prestashop>wexpay_254f642527b45bc260048e30704edb39'] = 'Configuration';
$_MODULE['<{wexpay}prestashop>wexpay_59586aa62e3b7e6e8c3aa86a2bcd8151'] = 'Créer un compte weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_cee9b3fae20d134d90dc128003aa81ec'] = 'Rien de plus simple, il vous suffit de vous rendre sur notre espace site marchand, et de remplir le formulaire de demande de contrat';
$_MODULE['<{wexpay}prestashop>wexpay_fe5fd4c042f1274174aec1c90a031e78'] = 'Activer facilement et gratuitement weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_d12218dc35a4cf0cd657c53a54725d4a'] = 'Vous avez signé un contrat avec weXpay, et vous avez reçu vos codes d\'activation dans un mail de bienvenue weXpay - Procédure = entrez vos indentifiant weXpay dans Prestashop pour activer le module et réalisez 3 transactions de test avec les codes de tests fournis dans le mail de bienvenue.';
$_MODULE['<{wexpay}prestashop>wexpay_96b34a13ce0fa2dd530e3c1a8cfeb1d0'] = 'Identifiant commerçant weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_b17f3f4dcf653a5776792498a9b44d6a'] = 'Mettre à jour';
$_MODULE['<{wexpay}prestashop>wexpay_0731cca0fad637eef981cc1e55ff39d4'] = 'Une fois que les transactions sont validées avec succès, connectez-vous à votre espace partenaire weXpay';
$_MODULE['<{wexpay}prestashop>wexpay_fd97030fded8ca936e46eaf835bda6f9'] = ': uploadez votre logo, et appuyer sur le bouton';
$_MODULE['<{wexpay}prestashop>wexpay_f93c54c7fabede2357a9ae7f9d21c7c3'] = '\"passage en production.\"';
$_MODULE['<{wexpay}prestashop>wexpay_a7d192c13f259fd2c8b1c918142c43e7'] = 'Pour plus d\'infos, cliquez-ici';
$_MODULE['<{wexpay}prestashop>wexpay_506fa25b2c14cf4d619dca91f1d6a970'] = ': acceptez le paiement en espèces et augmentez votre chiffre d\'affaires !';
